@@ -20,6 +20,7 @@
 #include <limits>
 #include <math.h>
 #include <stdlib.h>
+#include <new>
 
 #include <opus/opus_defines.h>
 
@@ -171,7 +172,7 @@ int Kwave::OpusDecoder::parseOpusTags(QWidget *widget, Kwave::FileInfo &info)
 	    break;
 	}
 	c      += 8;
-	length -= 8;
+	length -= 8; // length is [0...8] now
 
 	if (first_packet) {
 	    // the start of the first packet contains the software
@@ -179,7 +180,7 @@ int Kwave::OpusDecoder::parseOpusTags(QWidget *widget, Kwave::FileInfo &info)
 	    // read length of the comment
 	    quint32 len = qFromLittleEndian<quint32>(c);
 	    c      += 4;
-	    length -= 4;
+	    length -= 4; // length is [0...4] now
 	    if (len > length) {
 		// comment extends beyond end of packet
 		qWarning("OpusDecoder::parseHeader(): encoder name truncated "
@@ -206,11 +207,6 @@ int Kwave::OpusDecoder::parseOpusTags(QWidget *widget, Kwave::FileInfo &info)
 	}
 
 	while (fields && (length > 4)) {
-	    if (length < 4) {
-		qWarning("OpusDecoder::parseHeader(): broken comment (%lu)",
-			    length);
-		break;
-	    }
 	    quint32 len = qFromLittleEndian<quint32>(c);
 	    c      += 4;
 	    length -= 4;
@@ -426,7 +422,8 @@ int Kwave::OpusDecoder::open(QWidget *widget, Kwave::FileInfo &info)
     int rate_supp = Kwave::opus_next_sample_rate(rate_orig);
 
     // create a multi track sample buffer
-    m_buffer = new Kwave::MultiTrackSink<Kwave::SampleBuffer, true>(tracks);
+    m_buffer = new(std::nothrow)
+	Kwave::MultiTrackSink<Kwave::SampleBuffer, true>(tracks);
     Q_ASSERT(m_buffer);
     if (!m_buffer) return -1;
 
@@ -437,8 +434,8 @@ int Kwave::OpusDecoder::open(QWidget *widget, Kwave::FileInfo &info)
 	qDebug("    OpusDecoder::open(): converting sample rate: %d -> %d",
 	       rate_supp, rate_orig);
 
-	m_rate_converter =
-	    new Kwave::MultiTrackSource<Kwave::RateConverter, true>(tracks);
+	m_rate_converter = new(std::nothrow)
+	    Kwave::MultiTrackSource<Kwave::RateConverter, true>(tracks);
 	Q_ASSERT(m_rate_converter);
 	if (!m_rate_converter) ok = false;
 
